###########################################################################
#
# BasClas.pm -- base class for all classifiers
# A component of the Greenstone digital library software
# from the New Zealand Digital Library Project at the 
# University of Waikato, New Zealand.
#
# Copyright (C) 2000 New Zealand Digital Library Project
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
###########################################################################

package BasClas;

use parsargv;


sub print_general_usage {
    my ($plugin_name) = @_;
    print STDERR "\n  usage: plugin $plugin_name [options]\n\n";
}

# print_usage should be overridden for any sub-classes
sub print_usage {
    print STDERR "\nThis classifier has no classifier-specific options\n\n";

}

sub new {
    my $class = shift (@_);
    my $name = shift (@_);

    my $self = {};

    $self->{'outhandle'} = STDERR;
    
    # general options available to all classifiers
    if (!parsargv::parse(\@_,
			 q^builddir/.*/^, \$self->{'builddir'},
			 q^outhandle/.*/STDERR^, \$self->{'outhandle'},
			 q^verbosity/\d/2^, \$self->{'verbosity'},
			 "allow_extra_options")) {
	
	print STDERR "\nThe $name classifier uses an incorrect general option\n";
	print STDERR "(general options are those available to all classifiers).\n";
	print STDERR "Check your collect.cfg configuration file.\n";
    	&print_general_usage($plugin_name);
	die "\n";
    }



    return bless $self, $class;
}

sub init {
    my $self = shift (@_);
}

sub classify {
    my $self = shift (@_);
    my ($doc_obj) = @_;

    my $outhandle = $self->{'outhandle'};
    print $outhandle "BasClas::classify function must be implemented in sub-class\n";
}

sub get_classify_info {
    my $self = shift (@_);

    my $outhandle = $self->{'outhandle'};
    print $outhandle "BasClas::classify function must be implemented in sub-class\n";
}

1;
